@@ -1,8 +1,5 @@
 # -*- coding: utf-8 -*-
-import os, sys
-from platformdirs import PlatformDirs
-import platform
-import pathlib
+import os
 
 def get_version():
     HERE = os.path.dirname(__file__)
